@@ -2,7 +2,7 @@ package Catmandu::Error;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Moo;
 use namespace::clean;
@@ -11,6 +11,11 @@ extends 'Throwable::Error';
 
 with 'Catmandu::Logger';
 
+has message => (
+  is => 'ro',
+  default => sub { "" },
+);
+
 sub BUILD {
     my ($self) = @_;
     my $msg = $self->log_message;
@@ -29,7 +34,7 @@ package Catmandu::BadVal;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Moo;
 use namespace::clean;
@@ -40,7 +45,7 @@ package Catmandu::BadArg;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Moo;
 use namespace::clean;
@@ -51,7 +56,7 @@ package Catmandu::NotImplemented;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Moo;
 use namespace::clean;
@@ -62,7 +67,7 @@ package Catmandu::NoSuchPackage;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Moo;
 use namespace::clean;
@@ -82,7 +87,7 @@ package Catmandu::FixParseError;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Moo;
 use namespace::clean;
@@ -95,7 +100,7 @@ package Catmandu::NoSuchFixPackage;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Moo;
 use namespace::clean;
@@ -117,7 +122,7 @@ package Catmandu::BadFixArg;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Moo;
 use namespace::clean;
@@ -132,7 +137,7 @@ package Catmandu::FixError;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Moo;
 use namespace::clean;
@@ -146,7 +151,7 @@ package Catmandu::HTTPError;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Catmandu::Util qw(is_string);
 use Moo;
