@@ -2,7 +2,7 @@ package Catmandu::Fix;
 
 use Catmandu::Sane;
 
-our $VERSION = '1.0001';
+our $VERSION = '1.0002';
 
 use Catmandu;
 use Catmandu::Util qw(:is :string :misc);
@@ -183,24 +183,33 @@ sub emit {
     }
 
     if ($self->tidy || $self->log->is_debug) {
-        require Perl::Tidy;
+        try {
+            my $pkg = require_package 'Perl::Tidy';
+            my $sub = do {
+                no strict 'refs';
+                \&{"${pkg}::perltidy"};
+            };
 
-        my $tidy_perl = "";
-        my $err = "";
-        my $log = "";
+            my $tidy_perl = "";
+            my $err = "";
+            my $log = "";
 
-        my $has_err = Perl::Tidy::perltidy(
-            argv        => "-se",
-            source      => \$perl,
-            destination => \$tidy_perl,
-            logfile     => \$log,
-            stderr      => \$err,
-        );
-        if ($has_err) {
-            Catmandu::Error->throw($err);
-        }
+            my $has_err = $sub->(
+                argv        => "-se",
+                source      => \$perl,
+                destination => \$tidy_perl,
+                logfile     => \$log,
+                stderr      => \$err,
+            );
+            if ($has_err) {
+                Catmandu::Error->throw($err);
+            }
+
+            $perl = $tidy_perl;
+        } catch_case [
+            'Catmandu::NoSuchPackage' => sub {},
+       ];
 
-        $perl = $tidy_perl;
     }
 
     $self->log->debug($perl);
